# Security Policy

## Supported Versions

| Version | Supported          |
| ------- | ------------------ |
| 0.0.x   | :white_check_mark: |

## Reporting a Vulnerability

Send me a direct message [on Bsky](https://bsky.app/profile/tatsh.bsky.social).
